==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/operation_pagination.dart <==
part of keyclic_sdk_api.api;

class OperationPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  OperationCollection embedded = null;

  PaginationLinks links = null;

  OperationPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  @override
  String toString() {
    return 'OperationPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  OperationPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new OperationCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  static List<OperationPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<OperationPagination>()
        : json.map((value) => new OperationPagination.fromJson(value)).toList();
  }

  static Map<String, OperationPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, OperationPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new OperationPagination.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.4.tar.gz: lib/model/operation_pagination.dart <==
part of keyclic_sdk_api.api;

class OperationPagination {
  OperationPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  OperationPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = OperationCollection.fromJson(json['_embedded']);
    links = PaginationLinks.fromJson(json['_links']);
  }

  int limit;

  int page;

  int pages;

  int total;

  OperationCollection embedded;

  PaginationLinks links;

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  @override
  String toString() {
    return 'OperationPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  static List<OperationPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? List<OperationPagination>()
        : json.map((value) => OperationPagination.fromJson(value)).toList();
  }

  static Map<String, OperationPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationPagination>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationPagination.fromJson(value));
    }
    return map;
  }
}
